#	atom.h	Atomic data symbolics.				30-Jun-2008

define	ATOM	"|hydrogen|helium|carbon|nitrogen|oxygen|neon|sodium|magnesium|aluminum|silicon|sulfur|chlorine|argon|potassium|calcium|iron|nickel|selenium|krypton|"

#-------------------------------------------------------------------------------
# Atomic numbers:
define	UNKNOWN		 0
define	HYDROGEN	 1
define	HELIUM		 2
define	CARBON		 6
define	NITROGEN	 7
define	OXYGEN		 8
define	FLOURINE	 9
define	NEON		10
define	SODIUM		11
define	MAGNESIUM	12
define	ALUMINUM	13
define	SILICON		14
define	SULFUR		16
define	CHLORINE	17
define	ARGON		18
define	POTASSIUM	19
define	CALCIUM		20
define	IRON		26
define	NICKEL		28
define	SELENIUM	34
define	KRYPTON		36

define	N_ATOMS		24
define	N_STAGES	 8

#  Diagnostic types:
define	TEMDEN		"|density|temperature|emissivity|intensity|"
define	DENSITY		1
define	TEMPERATURE	2
define	EMISSIVITY	3
define	INTENSITY	4

#-------------------------------------------------------------------------------
