# DTRANS.H -- Transformation descriptor structure

define	LEN_TRNSTRUCT	3

define	TRN_NEFF	Memi[$1]	# number of effective stimuli
define	TRN_XEFF	Memi[$1+1]	# effective stimulus from xmode
define	TRN_YEFF	Memi[$1+2]	# effective stimuli from ymode
