# CALCNOISE.H -- Pseudocode instructions used by calcnoise

# Maximum length of a token

define	SZ_TOKEN	SZ_FNAME
define	SZ_STACK	8

# Tokens defined by parser generator

define	N_WRONG		257
define	N_LPAR		258
define	N_RPAR		259
define	N_READ		260
define	N_TIME		261
define	N_DONE		262
define	N_SWAP		263
define	N_NUM		264
define	N_FLUX		265
define	N_SQRT		266
define	N_LOG		267
define	N_MAG		268
define	N_ADD		269
define	N_SUB		270
define	N_MUL		271
define	N_DIV		272
define	N_EXP		273
define	N_NEG		274
