# Useful constants in cgs units

define PI 	3.14159274
define CLIGHT 	2.997925e10
define GRAV 	6.673e-8
define HPLANCK 	6.6262e-27
define KBOLTZ 	1.3806e-16
define SIGMA 	5.66956e-5
define MHYD 	1.67352e-24
define ECHARGE 	4.80325e-10
define MSUN 	1.989e33
define RSUN 	6.9599e10
define PC 	3.085678e18
define LSUN 	3.826e33
define YR 	3.1556925e7
define AU 	1.49597e13
define FJY	1.0E23
