# SIMTWO.H -- Constants used in simimg and simspec

define	RA_UNITS	"hours"      # right ascension units
define	DEC_UNITS	"degrees"    # target declination units
define	RADIUS_UNITS	"seconds"    # extended object radius units
define	OBJ_UNITS	"counts"     # units used when computing effstim
define	APER_UNITS	"seconds"    # aperture pixel size units
define	BACK_UNITS	"seconds"    # units of earthight and thermal spectra
define	ZOD_UNITS	"degrees"    # units of zodiacal light
define	ZOD_BAND	"band(v)"    # magnitude passband of zodiacal light
