#  neb_io.h --	Include file for tabular I/O for NEBULAR tasks
#
#  Output diagnostics column numbers

define	ID_COL		 1	# Nebula name
define	RG_COL		 2	# Nebula region code
define	N_S2_COL	 3	# Density from  [S ii]		10.4 eV
define	N_O2_COL	 4	# Density from  [O ii]		13.6 eV
define	N_CL3_COL	 5	# Density from [Cl iii]		23.8 eV
define	N_C3_COL	 6	# Density from   C iii]		24.4 eV
define	N_AR2_COL	 7	# Density from [Ar ii]		15.8 eV
define	N_AR4_COL	 8	# Density from [Ar iv]		40.9 eV
define	N_NE4_COL	 9	# Density from [Ne iv]		63.5 eV

define	T_S2_COL	10	# Temperature from  [S ii]	10.4 eV
define	T_O2_COL	11	# Temperature from  [O ii]	13.6 eV
define	T_N2_COL	12	# Temperature from  [N ii]	14.5 eV
define	T_S3_COL	13	# Temperature from  [S iii]	23.4 eV
define	T_AR3_COL	14	# Temperature from [Ar iii]	27.6 eV
define	T_O3_COL	15	# Temperature from  [O iii]	35.1 eV
define	T_AR4_COL	16	# Temperature from [Ar iv]	40.9 eV
define	T_NE3_COL	17	# Temperature from [Ne iii]	41.1 eV
define	T_AR5_COL	18	# Temperature from [Ar v]	59.8 eV
define	T_NE5_COL	19	# Temperature from [Ne v]	97.0 eV

define	N_LOW_COL	20	# Density of low-ionization zone
define	N_MED_COL	21	# Density of medium-ionization zone
define	N_HI_COL	22	# Density of high-ionization zone
define	T_LOW_COL	23	# Temperature of low-ionization zone
define	T_MED_COL	24	# Temperature of medium-ionization zone
define	T_HI_COL	25	# Temperature of high-ionization zone
#define	T_NE4_COL	26	# Temperature from [Ne iv]

define	N_OTCOLS	26	# No. potential tem/den diagnostics
