# GRAFPLOT.H -- Parameters which control the plot format

# Position of parameter in the format array

define	BWIDTH		1
define	BDEPTH		2
define	SWIDTH		3
define	SDEPTH		4
define	TWIDTH		5

define	LENFMT		5
# All units are in multiples of the character size

define	TXINC		0.1
define	TXMIN		0.2
