# GF.H -- Constants used internally by the gf library

define	SZ_KEYWORD	8
define	SZ_SHORTSTR	32
define	MAXDB		128

define	TYPE_LIST	"|stf|fxf|oif|plf|qpf|"

define	UNKNOWN_FMT	0
define	GEIS_FMT	1
define	FITS_FMT	2
define	IRAF_FMT	3
define	PIXLIST_FMT	4
define	QPOE_FMT	5

define	KEYSTRING	"|gcount|psize|pcount|group|bitpix|szgroup|"

define	GCOUNT_KEY	1
define	PSIZE_KEY	2
define	PCOUNT_KEY	3
define	GROUP_KEY	4
define	BITPIX_KEY	5
define	SZGROUP_KEY	6

define	NOT_FOUND	0
define	IS_FOUND	1
define	CMT_FOUND	2
define	HIST_FOUND	3

define	PARAM_DB	1
define	PARAM_GN	2
define	PARAM_EXTEND	3
define	PARAM_INHERIT	4
define	PARAM_UPDATE	5
define	PARAM_HIST	6
