define	C		2.9979e5
define	C18		2.9979e18
define	LN2		0.69314718
define	CLN10		6.90292e5
define	TWOPI		6.283185308
define	FOURPI		12.56637062
define	FOURPI2		39.47841763
define	ROOT2PI		2.50662828
define	PIE2MC		0.02654
define	CCM		2.9979e10
define  PLANCK		6.6262e-27
define  K		1.3806e-16


define	MAXSAMPLE	20
define	MAXPTS		16384
define	MAXPTS2		8192
define	MAXPAR		500
define	MAXFREE		200
define	NCOMP		200
define	PARPERC		7
define	NKEYS		21

define	SZ_CNAME	12
define	MAXLOG		5

define	NMODMAX		50
define	PTSMODMAX	50000
