# Include file for STSDAS stplot.sgraph task

define	SZ_BUF		2048		# Initial pixel buffer size
define	MAX_CURVES	14		# maximum curves if overplotting
define	LIST_OP		1
define	IMAGE_OP	2
define	TABLE_OP	3
define	DEF_MARG	0.025		# Default plot margins
define	DEF_COLOR	1

define	LNP_SOLID	1
define	LNP_DASH	2
define	LNP_DOT		3
define	LNP_DOTD	4

define	CRV_STRT	1
define	CRV_PSEUH	2
define	CRV_FULLH	3
