.help psk.h 1May92 plot
.ih
NAME
psk.h -- PSK metacode definitions.
.ih
HISTORY
.nf
  25Jul91 - Copied from sys$gio/sgikern/sgk.h and modified for psikern
            Jonathan D. Eisenhamer, STScI.
.fi
.ih
SEE ALSO
t_psikern
.endhelp
#---------------------------------------------------------------------------

# Max size of graphcap DD string.
define	SZ_DDSTR 256

# OS dispose command size from graphcap
define SZ_OSCMD 256

# Define the maximum number of characters allowed on a line.
define MAX_CHAR 72

#---------------------------------------------------------------------------
# End of psk.h
#---------------------------------------------------------------------------
