# SYNPHOT.H -- Constants used by the synphot library

define	DEFMIN		500.0	# Default minimum wavelength
define	DEFMAX	      26000.0	# Default maximum wavelength
define	ABZERO	      (-48.60)	# zero point of the AB magnitude system
define	STZERO	      (-21.10)	# zero point of the ST magnitude system
define	HSTAREA    45238.93416	# HST primary mirror area
