# FTERR.H -- Error information for Fourier analysis

define	FT_WARN		1
define	FT_ERROR	2
define	FT_FATAL	3

define	FT_NOINPUT	101
define	FT_NOOUTPUT	102
define	FT_BADNAXIS	103
define	FT_NOFTPAIRS	104
